Работа с ответом — Grab 0.6.30 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »

# Работа с ответом

## Объект Reponse

Результатом обработки запроса является объект класса `Response`. Вы можете получить к нему доступ через аттрибут response:

    g.go('http://mail.ru')
    print g.response.headers['Content-Type']

Смотрите полный перечень аттрибутов и методов объекта Response в API справочнике `Response`. Самое важное, что вам нужно знать:

body: | оригинальное тело ответа
unicode_body(): | тело ответа, приведённое к unicode-представлению
code: | HTTP-статус ответа
headers: | HTTP-заголовки ответа
charset: | кодировка документа
cokies: | кукисы ответа
url: | URL документа. В случае автоматической обработки редиректов, этот URL может отличаться от запрашиваемого.

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »